summaryrefslogtreecommitdiffstats
path: root/fs/fat/misc.c
diff options
context:
space:
mode:
authorRalf Baechle <ralf@linux-mips.org>1999-06-13 16:29:25 +0000
committerRalf Baechle <ralf@linux-mips.org>1999-06-13 16:29:25 +0000
commitdb7d4daea91e105e3859cf461d7e53b9b77454b2 (patch)
tree9bb65b95440af09e8aca63abe56970dd3360cc57 /fs/fat/misc.c
parent9c1c01ead627bdda9211c9abd5b758d6c687d8ac (diff)
Merge with Linux 2.2.8.
Diffstat (limited to 'fs/fat/misc.c')
-rw-r--r--fs/fat/misc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/fs/fat/misc.c b/fs/fat/misc.c
index b398a0bbd..1dfddd3c7 100644
--- a/fs/fat/misc.c
+++ b/fs/fat/misc.c
@@ -51,11 +51,11 @@ void fat_fs_panic(struct super_block *s,const char *msg)
/*
* is_binary selects optional text conversion based on the conversion mode and
* the extension part of the file name.
*/
-int is_binary(char conversion,char *extension)
+int fat_is_binary(char conversion,char *extension)
{
char *walk;
@@ -51,11 +51,11 @@ void fat_fs_panic(struct super_block *s,const char *msg)
/*
- * is_binary selects optional text conversion based on the conversion mode and
- * the extension part of the file name.
+ * fat_is_binary selects optional text conversion based on the conversion mode
+ * and the extension part of the file name.
*/